@@ -5,6 +5,6 @@ from django.contrib import admin
 
 class CredentialAdmin(admin.ModelAdmin):
     search_fields = ("endpoint",)
-    list_display = ("endpoint","user",)
+    list_display = ("integration_type", "environment", "endpoint", "user", )
     filter_horizontal = ("environments",)
     save_on_top = True
\ No newline at end of file
