@@ -16,13 +16,27 @@ class CredentialType(BaseModel):
     DBMONITOR = 3
     ZABBIX = 4
     FLIPPER = 5
-    
+    VM = 6
+    MYSQL = 7
+    MONGODB = 8
+    DNSAPI = 9
+    ACLAPI= 10
+    LAAS = 11
+    LOGNIT = 12
+
     INTEGRATION_CHOICES = (
         (CLOUDSTACK, 'Cloud Stack'),
         (NFSAAS, 'NFS as a Service'),
         (DBMONITOR, 'Database Monitor'),
         (ZABBIX, 'Zabbix'),
         (FLIPPER, 'Flipper'),
+        (VM, 'Virtual machine credentials'),
+        (MYSQL, 'MySQL credentials'),
+        (MONGODB, 'MongoDB credentials'),
+        (DNSAPI, 'DNS API'),
+        (ACLAPI, 'ACL API'),
+        (LAAS, 'Log as a Service'),
+        (LOGNIT, 'Lognit')
     )
     name = models.CharField(verbose_name=_("Name"),
                                          max_length=100,
@@ -34,11 +48,11 @@ class CredentialType(BaseModel):
         permissions = (
             ("view_integrationtype", "Can view integration type."),
         )
-    
+
 
 class Credential(BaseModel):
 
-    user = models.CharField(verbose_name=_("User."),
+    user = models.CharField(verbose_name=_("User"),
                             max_length=100,
                             help_text=_("User used to authenticate."),
                             blank=True,
@@ -69,6 +83,9 @@ class Credential(BaseModel):
     def __unicode__(self):
         return "%s" % (self.id)
 
+    def environment(self):
+        return ', '.join([e.name for e in self.environments.all()])
+        
     class Meta:
         permissions = (
             ("view_integrationcredential", "Can view integration credential."),
